summaryrefslogtreecommitdiffstats
path: root/minui
diff options
context:
space:
mode:
authorAjay Dudani <adudani@codeaurora.org>2015-02-05 01:51:34 +0100
committerElliott Hughes <enh@google.com>2015-02-11 01:28:07 +0100
commit07d9627d7cf31e03b778bc4b1c918d552680cd28 (patch)
treec983f27f5b1cd5b9b44d365f082c8a318ce2b418 /minui
parentMerge "recovery: Generate libminui dynamic library" (diff)
downloadandroid_bootable_recovery-07d9627d7cf31e03b778bc4b1c918d552680cd28.tar
android_bootable_recovery-07d9627d7cf31e03b778bc4b1c918d552680cd28.tar.gz
android_bootable_recovery-07d9627d7cf31e03b778bc4b1c918d552680cd28.tar.bz2
android_bootable_recovery-07d9627d7cf31e03b778bc4b1c918d552680cd28.tar.lz
android_bootable_recovery-07d9627d7cf31e03b778bc4b1c918d552680cd28.tar.xz
android_bootable_recovery-07d9627d7cf31e03b778bc4b1c918d552680cd28.tar.zst
android_bootable_recovery-07d9627d7cf31e03b778bc4b1c918d552680cd28.zip
Diffstat (limited to 'minui')
-rw-r--r--minui/events.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/minui/events.c b/minui/events.c
index d98a774ef..9e4255dd7 100644
--- a/minui/events.c
+++ b/minui/events.c
@@ -80,8 +80,8 @@ int ev_init(ev_callback input_cb, void *data)
}
/* TODO: add ability to specify event masks. For now, just assume
- * that only EV_KEY and EV_REL event types are ever needed. */
- if (!test_bit(EV_KEY, ev_bits) && !test_bit(EV_REL, ev_bits)) {
+ * that only EV_KEY, EV_REL & EV_SW event types are ever needed. */
+ if (!test_bit(EV_KEY, ev_bits) && !test_bit(EV_REL, ev_bits) && !test_bit(EV_SW, ev_bits)) {
close(fd);
continue;
}